@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
 our $DATE = '2015-10-08'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 use 5.010;
 use strict;
@@ -594,7 +594,7 @@ sub delete_section {
 
     if ($opts->{cond}) {
         @line_ranges = grep {
-            !$opts->{cond}->(
+            $opts->{cond}->(
                 $self,
                 linum_start => $_->[0],
                 linum_end   => $_->[1],
@@ -641,7 +641,7 @@ sub delete_key {
     if ($opts->{cond}) {
         @linums = grep {
             my $line = $self->{_parsed}[$_-1];
-            !$opts->{cond}->(
+            $opts->{cond}->(
                 $self,
                 linum     => $_,
                 parsed    => $line,
@@ -740,7 +740,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.22 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-10-08.
+This document describes version 0.23 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2015-10-08.
 
 =head1 SYNOPSIS
 
